library(data.table)
library(tidyverse)
library(caret)
library(pROC)
library(nnet)

######### Read data #########
rho.hat_PET = fread("C:/Users/pc/Desktop/Logistic/Empirical analysis/2-source(0.95)/rho.hat_PET.csv") %>% as.matrix() %>% .[,1:100]
rho.hat_MRI = fread("C:/Users/pc/Desktop/Logistic/Empirical analysis/2-source(0.95)/rho.hat_MRI.csv") %>% as.matrix() %>% .[,1:235]

MMSE = fread("C:/Users/pc/Desktop/Logistic/Empirical analysis/2-source(0.95)/MMSE.csv", header = F) %>% .$V1
researchGroup = fread("C:/Users/pc/Desktop/Logistic/Empirical analysis/2-source(0.95)/researchGroup.csv", header = F) %>% .$V1
researchGroup[researchGroup == "EMCI"] = "MCI"
researchGroup[researchGroup == "LMCI"] = "MCI"

M1 = rho.hat_PET %>% ncol()
M2 = rho.hat_MRI %>% ncol()
NN = c(327, 315, 72); N = sum(NN); M1; M2



### Constructing missing principal components ###
rho.hat_PET_NA = matrix(NA, N, M1)
rho.hat_PET_NA[1:sum(NN[1:2]),] = rho.hat_PET

rho.hat_MRI_NA = matrix(NA, N, M2)
rho.hat_MRI_NA[1:NN[1],] = rho.hat_MRI[1:NN[1],]
rho.hat_MRI_NA[(sum(NN[1:2])+1):N,] = rho.hat_MRI[(NN[1]+1):(NN[1]+NN[3]),]


### CMI imputation ###
# Zero-mean imputation as initial value #
rho.hat_MRI_hat<-t(matrix(apply(rho.hat_MRI_NA[c(1:NN[1],(sum(NN[1:2])+1):N),], 2, mean), M2, NN[2]))
rho.hat_MRI_NA[(NN[1]+1):sum(NN[1:2]),] = rho.hat_MRI_hat

rho.hat_PET_hat<-t(matrix(apply(rho.hat_PET_NA[1:sum(NN[1:2]),], 2, mean), M1, NN[3]))
rho.hat_PET_NA[(sum(NN[1:2])+1):N,] = rho.hat_PET_hat

# Iterative regression #
n_iter = 50
for(j in 1:n_iter)
{
  rho.hat_MRI_hat = matrix(0,NN[2],M2)
  for (i in 1:M2) {
    fit = lm(rho.hat_MRI_NA[,i]~., data = as.data.frame(rho.hat_PET_NA))
    rho.hat_MRI_hat[,i] = cbind(rep(1,NN[2]),rho.hat_PET_NA[(NN[1]+1):sum(NN[1:2]),])%*%fit$coefficients
  }
  rho.hat_MRI_NA[(NN[1]+1):sum(NN[1:2]),] = rho.hat_MRI_hat
  
  rho.hat_PET_hat = matrix(0,NN[3],M1)
  for (i in 1:M1) {
    fit = lm(rho.hat_PET_NA[,i]~., data = as.data.frame(rho.hat_MRI_NA))
    rho.hat_PET_hat[,i] = cbind(rep(1,NN[3]),rho.hat_MRI_NA[(sum(NN[1:2])+1):N,])%*%fit$coefficients
  }
  rho.hat_PET_NA[(sum(NN[1:2])+1):N,] = rho.hat_PET_hat
}


### rho.hat_CMI as factor ###
score = cbind(rho.hat_PET_NA, rho.hat_MRI_NA)
z.hat = cov(score)

rho.hat_CMI = (rho.hat_PET_NA %*% eigen(z.hat)$vec[1:M1,1:(M1+M2)] + 
                 rho.hat_MRI_NA %*% eigen(z.hat)$vec[(M1+1):(M1+M2),1:(M1+M2)]) %>% scale() 


### Extract two categories for classification ###
researchGroup = researchGroup[which(researchGroup != "MCI")]
rho.hat_CMI = rho.hat_CMI[which(researchGroup != "MCI"),]


###### rep is the number of repetitions ###
###### prob is the training rate        ###
###### M is the number of factors       ###
###### N is the sample size             ###

M = c(1:(M1+M2))
rep = 100; prob = 0.5
Accuracy = F1 = Sensitivity = Specificity = Precision = Recall = Mm = c()
for(l in 1:rep){
  
  ### divide the dataset ###
  folds = list(); accuracy_test = YY = YT = c(); iter = 3
  rho.hat_CMI_train = rho.hat_CMI_test = matrix(nrow = 0, ncol = (M1+M2))
  
  for(i in 1:iter){
    
    folds[[i]] = createDataPartition(researchGroup, p = prob, list = FALSE)
    
    rho.hat_CMI_train0 = rho.hat_CMI %>% .[folds[[i]],]
    rho.hat_CMI_train = rbind(rho.hat_CMI_train, rho.hat_CMI_train0)
    
    rho.hat_CMI_test0 = rho.hat_CMI %>% .[-folds[[i]],]
    rho.hat_CMI_test = rbind(rho.hat_CMI_test, rho.hat_CMI_test0)
    
    YY0 = c(researchGroup %>% .[folds[[i]]])
    YY = c(YY, YY0)
    
    YT0 = c(researchGroup %>% .[-folds[[i]]])
    YT = c(YT, YT0)
    
  }
  
  
  AIC_model = c()
  for(m in 1:length(M)){
    
    ### train data ###
    Group = YY
    data = data.frame(cbind(rho.hat_CMI_train[,1:M[m]]), Group)
    data$Group = factor(data$Group)
    
    mult.model = multinom(Group ~ ., data = data, MaxNWts = 10000)
    AIC_model[m] = mult.model$AIC
    
  }
  m = which.min(AIC_model)
  Mm[l] = M[m]
  
  
  ### train data ###
  Group = YY
  data = data.frame(cbind(rho.hat_CMI_train[,1:M[m]]), Group)
  data$Group = factor(data$Group)
  
  mult.model = multinom(Group ~ ., data = data, MaxNWts = 10000)
  predlab = predict(mult.model, newdata = data, type = "class")
  confum_train = confusionMatrix(data = predlab, reference = data$Group, mode = "everything")
  accuracy_train = confum_train$overall[1]
  
  
  ### test data ###
  Group = YT
  data = data.frame(cbind(rho.hat_CMI_test[,1:M[m]]), Group)
  data$Group = factor(data$Group)
  
  predlab = predict(mult.model, newdata = data, type = "class")
  confum_test = confusionMatrix(data = predlab, reference = data$Group, mode = "everything")
  accuracy_test = confum_test$overall[1]
  
  confumat_test = as.data.frame(confum_test$table)
  ggplot(confumat_test, aes(x = Reference, y = Prediction)) +
    geom_tile(aes(fill = Freq)) +
    geom_text(aes(label = Freq)) + 
    scale_fill_gradient(low = "steelblue", high = "lightgreen", guide = "colorbar") +
    ggtitle("mlogit")
  
  summary_test = multiClassSummary(
    data.frame(obs = data$Group, pred = predlab), lev = levels(data$Group))
  
  Accuracy[l] = summary_test[1]
  Sensitivity[l] = summary_test[4]
  Specificity[l] = summary_test[5]
  
}

Accuracy_mean = mean(Accuracy)
Sensitivity_mean = mean(Sensitivity)
Specificity_mean = mean(Specificity)

print(c(Accuracy_mean, Sensitivity_mean, Specificity_mean))