MFPCA <- function(x_co, k1, k2, t.1h, t.2h){
  
  #################################################
  ##### Computing the FPC scores and curves for each data source by SVD method #############
  
  s1<-svd(x_co[,1:T1]/sqrt(N) )                                         ## SVD for x.1 on the all data 
  phi.1.hat<-t(s1$v[,1:k1]) * (t.1h/T1)^(-0.5)                          ## The univariate FPC curves of x.1 with order k1*T1
  x.1.score<-x_co[,1:T1] %*% t(phi.1.hat) * (t.1h/T1)                   ## The univariate FPC scores of x.1 with order N*k1
  
  s2<-svd(x_co[,(T1+1):(T1+T2)]/sqrt(N) )                               ## SVD for x.2 on the all data 
  phi.2.hat<-t(s2$v[,1:k2]) * (t.2h/T2)^(-0.5)                          ##  The univariate FPC curves of x.2 with orderk2*T2
  x.2.score<-x_co[,(T1+1):(T1+T2)] %*% t(phi.2.hat) * (t.2h/T2)         ##  The univariate FPC score of x.2 with order N*k2
 
  ##### The end of Computing the FPC scores and curves for each data source by SVD method #############  
  #################################################
 
  
  #################################################
  ##### Computing the Multi-source FPC scores and curves by the method in Ma's paper#############
 
  score<-cbind(x.1.score,x.2.score)
  z.hat<-t(score) %*% score /(N-1)
  
  psi.1.hat<-t(eigen(z.hat)$vec[1:k1,1:(k1+k2)]) %*% phi.1.hat            ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2)*T1
  psi.2.hat<-t(eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2)]) %*% phi.2.hat   ## The estimated Multivariate FPC eigenfunctions of x.2 with order (k1+k2)*T2
  
  rho_std_temp<-x.1.score%*% eigen(z.hat)$vec[1:k1,1:(k1+k2)] + x.2.score %*% eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2)]  ## The estimated multivariate FPC scores with order N*(k1+k2) of the complete-data
  rho_std<-scale(rho_std_temp)[,1:M0]
  
  #####The end of  Computing the Multi-source FPC scores and curves by the method in Ma's paper#############
  #################################################
  
  return(list(rho_std, psi.1.hat, psi.2.hat))
  
}