generate_data_setting1_rho<-function(rho_0, phi.1, phi.2, alpha1, alpha2, alpha3, sd){
  
  # generating the covariance-variance matrix of two data sources.
  sigma<-matrix(NA,M1+M2,M1+M2)
  sigma[1:M1,1:M1]<-diag(exp(-(2:(M1+1))/2))
  sigma[(M1+1):(M1+M2),(M1+1):(M1+M2)]<-diag(exp(-(2:(M2+1))/2))
  
  R<-matrix(0,M1,M2)
  
  for (i in 1:M1){
    for (j in 1:M2){
      R[i,j]<-rho_0^(abs(i-j)+1)
    }
  } 
  
  sigma[1:M1,(M1+1):(M1+M2)]<-sigma[1:M1,1:M1]^0.5 %*% R %*% sigma[(M1+1):(M1+M2),(M1+1):(M1+M2)]^0.5
  sigma[(M1+1):(M1+M2),1:M1]<-t(sigma[1:M1,(M1+1):(M1+M2)])
  rr2<-eigen(sigma%*%sigma)
  sigma0.5<-rr2$vectors%*%diag(rr2$values^(0.5))%*%t(rr2$vectors)
  # The end of generating the covariance-variance matrix of two data sources.
  
  
  ## Generating the 2-source functional data ########
  ksi<-mvrnorm(N,rep(0,M1+M2),sigma0.5)   # ksi is an N*(M1+M2) matrix
  ksi.1<-ksi[,1:M1]                    # The PC socres of x.1
  ksi.2<-ksi[,(M1+1):(M1+M2)]          # The PC socres of x.2
  
  x.1<-ksi.1 %*% phi.1
  x.2<-ksi.2 %*% phi.2
  
  Z<-t(ksi) %*% ksi/(N-1)
  psi.1<-t(eigen(Z)$vec[1:M1,]) %*% phi.1            # MFPC curves of order (M1+M2)*T1
  psi.2<-t(eigen(Z)$vec[(M1+1):(M1+M2),]) %*%phi.2   # MFPC curves of order (M1+M2)*T2
  
  rho<-ksi.1 %*% eigen(Z)$vec[1:M1,1:(M1+M2)] + ksi.2 %*% eigen(Z)$vec[(M1+1):(M1+M2),1:(M1+M2)] # MFPC scores matrix with order N*(M1+M2)

  x<-rho %*% cbind(psi.1,psi.2)
  ## The end of Generating the 2-source functional data ########
  
  rho_std = scale(rho)
  p.1 = exp(rho_std[,1:M]%*% alpha1)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p.2 = exp(rho_std[,1:M]%*% alpha2)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p.3 = exp(rho_std[,1:M]%*% alpha3)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p = cbind(p.1, p.2, p.3)
  
  y_rho=c()
  for(i in 1:N){
    y_rho0 = which.max(rmultinom(1, size = 1, prob = p[i,]))
    y_rho=c(y_rho,y_rho0)
  }
  
  
  ## Computing the FPC scores and curves for each data source by SVD method ##
  s1<-svd(x[,1:T1]/sqrt(N))                                         ## SVD for x.1 on the all data 
  phi.1.hat<-t(s1$v[,1:M1]) * (t.1h/T1)^(-0.5)                      ## The univariate FPC curves of x.1 with order k1*T1
  x.1.score<-x[,1:T1] %*% t(phi.1.hat) * (t.1h/T1)                  ## The univariate FPC scores of x.1 with order N*k1
  
  s2<-svd(x[,(T1+1):(T1+T2)]/sqrt(N))                               ## SVD for x.2 on the all data 
  phi.2.hat<-t(s2$v[,1:M2]) * (t.2h/T2)^(-0.5)                      ## The univariate FPC curves of x.2 with orderk2*T2
  x.2.score<-x[,(T1+1):(T1+T2)] %*% t(phi.2.hat) * (t.2h/T2)        ## The univariate FPC score of x.2 with order N*k2
  ## The end of Computing the FPC scores and curves for each data source by SVD method ##
  
  
  ## Computing the Canonical scores ##
  Z1 = x.1.score
  Z2 = x.2.score
  
  Omega1 = Z1%*%solve(t(Z1)%*%Z1)%*%t(Z1)
  Omega2 = Z2%*%solve(t(Z2)%*%Z2)%*%t(Z2)
  
  evd = eigen(Omega1 + Omega2)
  f = evd$vectors[,1:M] 
  ## The end of  Computing the Canonical scores ##
  
  p_1 = exp(f[,1:M]%*% alpha1)/(exp(f[,1:M]%*% alpha1)+exp(f[,1:M]%*% alpha2)+exp(f[,1:M]%*% alpha3))
  p_2 = exp(f[,1:M]%*% alpha2)/(exp(f[,1:M]%*% alpha1)+exp(f[,1:M]%*% alpha2)+exp(f[,1:M]%*% alpha3))
  p_3 = exp(f[,1:M]%*% alpha3)/(exp(f[,1:M]%*% alpha1)+exp(f[,1:M]%*% alpha2)+exp(f[,1:M]%*% alpha3))
  p = cbind(p_1, p_2, p_3)
  
  y_f=c()
  for(i in 1:N){
    y_f0 = which.max(rmultinom(1, size = 1, prob = p[i,]))
    y_f=c(y_f,y_f0)
  }
  
  return(list(rho_std, x, y_rho, y_f, psi.1, psi.2))

}