MCCA_complete_data<-function(NN, N, T1, T2, x_std, t.1h, t.2h){
  
  ##### Computing the FPC scores and curves for each data source by SVD method #############  
  s1<-svd(x_std[1:sum(NN[1:2]),1:T1]/sqrt(sum(NN[1:2])))               ## SVD for x.1 on the observed data 
  phi.1.hat<-t(s1$v[,1:k1]) * (t.1h/T1)^(-0.5)                         ## The univariate FPC curves of x.1 with order k1*T1
  x.1.score<-x_std[1:sum(NN[1:2]),1:T1] %*% t(phi.1.hat) * (t.1h/T1)   ## The univariate FPC scores of x.1 with order (N1+N2)*k1
  
  x.1.score_NA<-matrix(NA,N,k1)
  x.1.score_NA[1:sum(NN[1:2]),]<- x.1.score
  
  s2<-svd(x_std[c(1:NN[1],(sum(NN[1:2])+1):N),(T1+1):(T1+T2)]/sqrt(N-NN[2]))                    ## SVD for x.2 on the observed data 
  phi.2.hat<-t(s2$v[,1:k2]) * (t.2h/T2)^(-0.5)                                                  ## The univariate FPC curves of x.2 with order k2*T2
  x.2.score<-x_std[c(1:NN[1],(sum(NN[1:2])+1):N),(T1+1):(T1+T2)] %*% t(phi.2.hat) * (t.2h/T2)      ##  The univariate FPC score of x.2 with order (N-N2)*k2
  
  x.2.score_NA<-matrix(NA,N,k2)
  x.2.score_NA[1:NN[1],]<- x.2.score[1:NN[1],]
  x.2.score_NA[(sum(NN[1:2])+1):N,]<- x.2.score[(NN[1]+1):(NN[1]+NN[3]),]
  ##### The end of Computing the FPC scores and curves for each data source by SVD method #############  
  
  
  score<-cbind(x.1.score[1:NN[1],],x.2.score[1:NN[1],])   ##  N1*(k1+k2)
  z.hat<-t(score) %*% score /(NN[1]-1)
  
  psi.1.hat<-t(eigen(z.hat)$vec[1:k1,1:(k1+k2)]) %*% phi.1.hat   ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2)*T1
  psi.2.hat<-t(eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2)]) %*% phi.2.hat ## The estimated Multivariate FPC eigenfunctions of x.2 with order (k1+k2)*T2
  
  
  ######### The Canonical scores of x.1 and x.2 on the complete-data #########
  Z1 = x.1.score[1:NN[1],]
  Z2 = x.2.score[1:NN[1],]
  
  Omega1 = Z1%*%solve(t(Z1)%*%Z1)%*%t(Z1)
  Omega2 = Z2%*%solve(t(Z2)%*%Z2)%*%t(Z2)
  
  evd = eigen(Omega1 + Omega2)
  f_com = evd$vectors[,1:M0] 
  
  return(list(psi.1.hat,psi.2.hat,x.1.score_NA,x.2.score_NA,f_com))
  
}