generate_data_setting1_rho<-function(rho_0, phi.1, phi.2, alpha1, alpha2, alpha3, sd){
  
  # generating the covariance-variance matrix of two data sources.
  sigma<-matrix(NA,M1+M2,M1+M2)
  sigma[1:M1,1:M1]<-diag(exp(-(2:(M1+1))/2))
  sigma[(M1+1):(M1+M2),(M1+1):(M1+M2)]<-diag(exp(-(2:(M2+1))/2))
  
  R<-matrix(0,M1,M2)
  
  for (i in 1:M1){
    for (j in 1:M2){
      R[i,j]<-rho_0^(abs(i-j)+1)
    }
  } 
  
  sigma[1:M1,(M1+1):(M1+M2)]<-sigma[1:M1,1:M1]^0.5 %*% R %*% sigma[(M1+1):(M1+M2),(M1+1):(M1+M2)]^0.5
  sigma[(M1+1):(M1+M2),1:M1]<-t(sigma[1:M1,(M1+1):(M1+M2)])
  rr2<-eigen(sigma%*%sigma)
  sigma0.5<-rr2$vectors%*%diag(rr2$values^(0.5))%*%t(rr2$vectors)
  # The end of generating the covariance-variance matrix of two data sources.
  
  
  ## Generating the 2-source functional data ########
  ksi<-mvrnorm(N,rep(0,M1+M2),sigma0.5)   # ksi is an N*(M1+M2) matrix
  ksi.1<-ksi[,1:M1]                    # The PC socres of x.1
  ksi.2<-ksi[,(M1+1):(M1+M2)]          # The PC socres of x.2
  
  x.1<-ksi.1 %*% phi.1
  x.2<-ksi.2 %*% phi.2
  
  Z<-t(ksi) %*% ksi/(N-1)
  psi.1<-t(eigen(Z)$vec[1:M1,]) %*% phi.1            # MFPC curves of order (M1+M2)*T1
  psi.2<-t(eigen(Z)$vec[(M1+1):(M1+M2),]) %*%phi.2   # MFPC curves of order (M1+M2)*T2
  
  rho<-ksi.1 %*% eigen(Z)$vec[1:M1,1:(M1+M2)] + ksi.2 %*% eigen(Z)$vec[(M1+1):(M1+M2),1:(M1+M2)] # MFPC scores matrix with order N*(M1+M2)

  x<-rho %*% cbind(psi.1,psi.2)
  ## The end of Generating the 2-source functional data ########
  
  rho_std = scale(rho)
  p.1 = exp(rho_std[,1:M]%*% alpha1)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p.2 = exp(rho_std[,1:M]%*% alpha2)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p.3 = exp(rho_std[,1:M]%*% alpha3)/(exp(rho_std[,1:M]%*% alpha1)+exp(rho_std[,1:M]%*% alpha2)+exp(rho_std[,1:M]%*% alpha3))
  p.0 = cbind(p.1, p.2, p.3)
  
  y=c()
  for(i in 1:N){
    y0 = which.max(rmultinom(1, size = 1, prob = p.0[i,]))
    y=c(y,y0)
  }
  
  return(list(rho_std, x, y, psi.1, psi.2))
  
}