library(stargazer)
library(funData)
library(caret)
library(MASS)
library(nnet)

N<-300     ## The sample size

M1<-25     ## The number of PC scores of x(1)
T1<-200    ## The number of sample point of curve x(1)

M2<-25     ## The number of PC scores of x(2)
T2<-300    ## The number of sample point of curve x(2)

k1<-10     ## The number of truncated PC scores of x(1) in Ma's paper
k2<-10     ## The number of truncated PC scores of x(2) in Ma's paper

## Regression coefficient vector
alpha1<-rep(0,10)
alpha2<-2*c(0.972,0.734,0.691,0.541,0.480,0.424,0.331,0.271,0.123,0.0405)
alpha3<-4*c(0.934,0.903,0.815,0.604,0.517,0.447,0.392,0.370,0.345,0.3)  
M<-length(alpha1)         ## The number of mulrivariate truncated PC scores

sd<-0.2                   ## The standard deviation of error in the regression model 

rho_0<-0.4                ## The correlation among data sources

## miss_ratio<-0 ##
gam1.1 = rep(1, (T1+T2))
gam1.2 = gam1.3 = rep(0, (T1+T2))

gam2.1 = rep(1, (T1+T2))
gam2.2 = gam2.3 = rep(0, (T1+T2))

gam3.1 = rep(1, (T1+T2))
gam3.2 = gam3.3 = rep(0, (T1+T2))


## miss_ratio<-0.2 ##           
gam1.1 = rep(1, (T1+T2))
gam1.2 = gam1.3 = rep(7/51, (T1+T2))

gam2.1 = rep(1, (T1+T2))
gam2.2 = gam2.3 = rep(1/18, (T1+T2))

gam3.1 = rep(1, (T1+T2))
gam3.2 = gam3.3 = rep(7/51, (T1+T2))


## miss_ratio<-0.6 ##         
gam1.1 = rep(1, (T1+T2))
gam1.2 = gam1.3 = rep(21/23, (T1+T2))

gam2.1 = rep(1, (T1+T2))
gam2.2 = gam2.3 = rep(3/14, (T1+T2))

gam3.1 = rep(1, (T1+T2))
gam3.2 = gam3.3 = rep(21/23, (T1+T2))


## miss_ratio<-0.9 ##         
gam1.1 = rep(1, (T1+T2))
gam1.2 = gam1.3 = rep(63/4, (T1+T2))

gam2.1 = rep(1, (T1+T2))
gam2.2 = gam2.3 = rep(9/22, (T1+T2))

gam3.1 = rep(1, (T1+T2))
gam3.2 = gam3.3 = rep(63/4, (T1+T2))


Iter.times<-300

setwd("C:/Users/pc/Desktop/Logistic/Setting1(MNAR)/")

##################################################################
######  Generating the eigenfunctions of setting 1 ######
source("generate_eigenfunction_setting1.R")
temp1 <- generate_eigenfunction_setting1(N, M1, T1, M2, T2)
t.1       <- temp1[[1]]
t.2       <- temp1[[2]]
phi.1     <- temp1[[3]]
phi.2     <- temp1[[4]]
t.1h      <- temp1[[5]]
t.2h      <- temp1[[6]]
#######  The end of Generating the eigenfunctions of setting 1 ######



##################################################################
######## generating data ####################
psi.1_std<-psi.2_std<-rho_std<-f.hat_com<-y<-x_std<-vector('list',Iter.times)

source("generate_data_setting1_rho.R")
for (times in 1:Iter.times) {
  temp1 <- generate_data_setting1_rho(rho_0, phi.1, phi.2, alpha1, alpha2, alpha3, sd)
  rho_std[[times]]    <- temp1[[1]]
  x_std[[times]]      <- temp1[[2]]
  y[[times]]          <- temp1[[3]]
  psi.1_std[[times]]  <- temp1[[4]]
  psi.2_std[[times]]  <- temp1[[5]]
  
}  
######## The end of generating data ########



##################################################################
######## generating missing pattern ####################
source("generate_missing_pattern.R")
for (times in 1:Iter.times){
  
  temp2 <- generate_missing_pattern(rho_std[[times]], x_std[[times]], y[[times]])
  NN                  <- temp2[[1]]
  rho_std[[times]]    <- temp2[[2]]
  x_std[[times]]      <- temp2[[3]]
  y[[times]]          <- temp2[[4]]
  
}
######## The end of generating missing pattern ########



M0=10
##################################################################
######### missing rate = 0 ####################
source("MCCA.R")
for (times in 1:Iter.times){
  
  temp2 <- MCCA(x_std[[times]], k1, k2, t.1h, t.2h)
  f.hat_com[[times]]   <- temp2[[1]]
  
}


Accuracy_com<-Precision_com<-Recall_com<-F1_com<-AIC_com<-array()

source("Factor_regression_Imputed_CCA.R")
for (times in 1:Iter.times){
  
  temp5 <- Factor_regression_Imputed_CCA(f.hat_com[[times]][1:NN[1],1:M0], y[[times]][1:NN[1]])
  Accuracy_com[times]       <- temp5[[1]]
  Precision_com[times]      <- temp5[[2]]
  Recall_com[times]         <- temp5[[3]]
  F1_com[times]             <- temp5[[4]]
  AIC_com[times]            <- temp5[[5]]
  
}

result_com <- round(c(mean(Accuracy_com),sd(Accuracy_com),
                      mean(Precision_com),mean(Recall_com),mean(na.omit(F1_com))),4)
print(result_com)

stargazer(result_com, title = "Evaluation",  align = F, type = "latex")
######### The end of missing rate = 0 ####################



M0=10
##################################################################
######### MCCA_complete_data #########
psi.1.hat<-psi.2.hat<-x.1.score_NA<-x.2.score_NA<-f.hat_com<-vector('list',Iter.times )

source("MCCA_complete_data.R")
for (times in 1:Iter.times){
  
  same<-MCCA_complete_data(NN, N, T1, T2, x_std[[times]],t.1h,t.2h)
  psi.1.hat[[times]]         <- same[[1]]
  psi.2.hat[[times]]         <- same[[2]]
  x.1.score_NA[[times]]      <- same[[3]]
  x.2.score_NA[[times]]      <- same[[4]]
  f.hat_com[[times]]         <- same[[5]]
  
}
######### The end of MFPCA_complete_data #########



##################################################################
######## Factor regression based on the CMI method #########
Accuracy_CMI<-Precision_CMI<-Recall_CMI<-F1_CMI<-AIC_CMI<-array()
x.1.score.hat<-x.2.score.hat<-f.hat_CMI<-vector('list',Iter.times)

source("Imputing_data_CMI.R")
for (times in 1:Iter.times){
  
  temp1 <- Imputing_data_CMI(NN, y[[times]], x.1.score_NA[[times]], x.2.score_NA[[times]])
  x.1.score.hat[[times]]    <- temp1[[1]]
  x.2.score.hat[[times]]    <- temp1[[2]]
  
}


source("Construct_factor_CCA.R")
for (times in 1:Iter.times){
  
  temp2 <- Construct_factor_CCA(x_std[[times]], psi.1.hat[[times]], psi.2.hat[[times]], x.1.score.hat[[times]], x.2.score.hat[[times]])
  f.hat_CMI[[times]]         <- temp2[[1]]

}


source("Factor_regression_Imputed_CCA.R")
for (times in 1:Iter.times){
  
  temp3 <- Factor_regression_Imputed_CCA(f.hat_CMI[[times]][,1:M0], y[[times]])
  Accuracy_CMI[times]        <- temp3[[1]]
  Precision_CMI[times]       <- temp3[[2]]
  Recall_CMI[times]          <- temp3[[3]]
  F1_CMI[times]              <- temp3[[4]]
  AIC_CMI[times]             <- temp3[[5]]
  
}
######## The end of factor regression based on the CMI method #########



##################################################################
######## Factor regression based on the MBI method #########
Accuracy_MBI<-Precision_MBI<-Recall_MBI<-F1_MBI<-AIC_MBI<-array()
x.1.score.hat<-x.2.score.hat<-f.hat_MBI<-vector('list',Iter.times)

source("Imputing_data_MBI.R")
for (times in 1:Iter.times){
  
  temp1 <- Imputing_data_MBI(NN, y[[times]], x.1.score_NA[[times]], x.2.score_NA[[times]])
  x.1.score.hat[[times]]    <- temp1[[1]]
  x.2.score.hat[[times]]    <- temp1[[2]]
  
}


source("Construct_factor_CCA.R")
for (times in 1:Iter.times){
  
  temp2 <- Construct_factor_CCA(x_std[[times]], psi.1.hat[[times]], psi.2.hat[[times]], x.1.score.hat[[times]], x.2.score.hat[[times]])
  f.hat_MBI[[times]]        <- temp2[[1]]

}


source("Factor_regression_Imputed_CCA.R")
for (times in 1:Iter.times){
  
  temp3 <- Factor_regression_Imputed_CCA(f.hat_MBI[[times]][,1:M0], y[[times]])
  Accuracy_MBI[times]       <- temp3[[1]]
  Precision_MBI[times]      <- temp3[[2]]
  Recall_MBI[times]         <- temp3[[3]]
  F1_MBI[times]             <- temp3[[4]]
  AIC_MBI[times]            <- temp3[[5]]
  
}
######## The end of factor regression based on the MBI method #########



#result----
result <- round(rbind(
  c(mean(Accuracy_CMI),sd(Accuracy_CMI),mean(Precision_CMI),mean(Recall_CMI),mean(na.omit(F1_CMI))),
  c(mean(Accuracy_MBI),sd(Accuracy_MBI),mean(Precision_MBI),mean(Recall_MBI),mean(na.omit(F1_MBI)))),4)
print(result)

stargazer(result, title = "Evaluation",  align = F, type = "latex")