MFPCA_setting2 <- function(x_co, k1, k2, k3, t.1h, t.2h, t.3h){
  
  #################################################
  ##### Computing the FPC scores and curves for each data source by SVD method #############
  
  s1<-svd(x_co[,1:T1]/sqrt(N))
  phi.1.hat<-t(s1$v[,1:k1]) * (t.1h/T1)^(-0.5)
  x.1.score<-x_co[,1:T1] %*% t(phi.1.hat) * (t.1h/T1) #The univariate FPCA of x.1
  
  s2<-svd(x_co[,(T1+1):(T1+T2)]/sqrt(N))
  phi.2.hat<-t(s2$v[,1:k2]) * (t.2h/T2)^(-0.5)
  x.2.score<-x_co[,(T1+1):(T1+T2)] %*% t(phi.2.hat) * (t.2h/T2) #The univariate FPCA of x.2
  
  s3<-svd(x_co[,(T1+T2+1):(T1+T2+T3)]/sqrt(N))
  phi.3.hat<-t(s3$v[,1:k3]) * (t.3h/T3)^(-0.5)
  x.3.score<-x_co[,(T1+T2+1):(T1+T2+T3)] %*% t(phi.3.hat) * (t.3h/T3) #The univariate FPCA of x.3
  
  ##### The end of Computing the FPC scores and curves for each data source by SVD method #############  
  #################################################
  
  
  #################################################
  ##### Computing the Multi-source FPC scores and curves by the method in Ma's paper#############
  
  score<-cbind(x.1.score,x.2.score,x.3.score)
  z.hat<-t(score) %*% score /(NN[1]-1)
  
  psi.hat.1<-t(eigen(z.hat)$vec[1:k1,1:(k1+k2+k3)]) %*% phi.1.hat ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2+k3)*T1
  psi.hat.2<-t(eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2+k3)]) %*% phi.2.hat## The estimated Multivariate FPC eigenfunctions of x.2 with order (k1+k2+k3)*T2
  psi.hat.3<-t(eigen(z.hat)$vec[(k1+k2+1):(k1+k2+k3),1:(k1+k2+k3)]) %*% phi.3.hat## The estimated Multivariate FPC eigenfunctions of x.3 with order (k1+k2+k3)*T3
  
  rho_std_temp<-x.1.score%*% eigen(z.hat)$vec[1:k1,1:(k1+k2+k3)] + 
                x.2.score %*% eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2+k3)] + 
                x.3.score %*% eigen(z.hat)$vec[(k1+k2+1):(k1+k2+k3),1:(k1+k2+k3)]  
  
  ## The estimated multivariate FPC scores with order N*(k1+k2+k3) of the complete-data
  rho_std<-scale(rho_std_temp)[,1:M0]
  #####The end of  Computing the Multi-source FPC scores and curves by the method in Ma's paper#############
  #################################################
  
  return(list(rho_std, psi.hat.1, psi.hat.2, psi.hat.3))
  
}