library(stargazer)
library(funData)
library(caret)
library(MASS)
library(nnet)

N<-300          ## The sample size

T11<-100        ## Image x(1): the sample number of x-axis
T12<-50         ## Image x(1): the sample number of y-axis
T1<-T11*T12     ## The number of sample point of Image x(1)
M11<-5          ## The number of PC scores of x(1) along x-axis
M12<-5          ## The number of PC scores of x(1) along y-axis
M1<-M11*M12     ## The number of PC scores of x(1)

T2<-200         ## The number of sample point of Image x(2)
M2<-25          ## The number of PC scores of x(2)

T3<-200         ## The number of sample point of Image x(3)
M3<-25          ## The number of PC scores of x(3)

k1=10           ## The number of truncated PC scores of x(1) in Ma's paper
k2=10           ## The number of truncated PC scores of x(2) in Ma's paper
k3=10           ## The number of truncated PC scores of x(3) in Ma's paper

gamma1<-0.3     ## The coefficient in generating MFPC curves  
gamma2<-0.3

## Regression coefficient vector
alpha1<-rep(0,10)
alpha2<-2*c(0.972,0.734,0.691,0.541,0.480,0.424,0.331,0.271,0.123,0.0405)
alpha3<-4*c(0.934,0.903,0.815,0.604,0.517,0.447,0.392,0.370,0.345,0.3)  
M<-length(alpha1)       ## The number of mulrivariate truncated PC scores 

sd <- 0.2               ## The standard deviation of error in the regression model 

miss_ratio<-0           ## Missing ratio .2 .6 .9

NN<-array() 
NN[1]<-N*(1-miss_ratio) ## The number of complete-data
NN[2:7]<-N*miss_ratio/6 ## The number of missing subjects 

Iter.times<-300

setwd("C:/Users/pc/Desktop/Logistic/Setting2(MCAR)/")

##################################################################
######  Generating the eigenfunctions of setting 3 ######
source("generate_eigenfunction_setting2.R")
temp1 <- generate_eigenfunction_setting2(N, M11, T11, M12, T12, M2, T2, M3, T3)
t.11            <- temp1[[1]]
t.12            <- temp1[[2]]
t.2             <- temp1[[3]]
t.3             <- temp1[[4]]
phi.1           <- temp1[[5]]
phi.2           <- temp1[[6]]
phi.3           <- temp1[[7]]
t.1h            <- temp1[[8]]
t.2h            <- temp1[[9]]
t.3h            <- temp1[[10]]
#######  The end of Generating the eigenfunctions of setting 3 ######



##################################################################
######## generating data ####################
psi.1_std<-psi.2_std<-psi.3_std<-rho_std<-rho_std_com<-y<-x_std<-vector('list',Iter.times)

source("generate_data_setting2.R")
for (times in 1:Iter.times) {
  
  temp1 <- generate_data_setting2(phi.1, phi.2, phi.3, alpha1, alpha2, alpha3, sd, gamma1, gamma2)
  rho_std[[times]]    <- temp1[[1]]
  x_std[[times]]      <- temp1[[2]]
  y[[times]]          <- temp1[[3]]
  psi.1_std[[times]]  <- temp1[[4]]
  psi.2_std[[times]]  <- temp1[[5]]
  psi.3_std[[times]]  <- temp1[[6]]
  
}  
######## The end of generating data ########



M0=10
##################################################################
######### missing rate = 0 ####################
source("MFPCA_setting2.R")
for (times in 1:Iter.times){
  
  temp2 <- MFPCA_setting2(x_std[[times]], k1, k2, k3, t.1h, t.2h, t.3h)
  rho_std_com[[times]]   <- temp2[[1]]
  
}


Accuracy_com<-Precision_com<-Recall_com<-F1_com<-AIC_com<-mse_alpha2<-mse_alpha3<-array()
alpha2.hat<-alpha3.hat<-vector('list',Iter.times )

source("Factor_regression_Imputed_PCA.R")
for (times in 1:Iter.times){
  
  temp5 <- Factor_regression_Imputed_PCA(rho_std_com[[times]], alpha2, alpha3, y[[times]][1:NN[1]])
  Accuracy_com[times]       <- temp5[[1]]
  Precision_com[times]      <- temp5[[2]]
  Recall_com[times]         <- temp5[[3]]
  F1_com[times]             <- temp5[[4]]
  AIC_com[times]            <- temp5[[5]]
  alpha2.hat[[times]]       <- temp5[[6]]
  alpha3.hat[[times]]       <- temp5[[7]]
  mse_alpha2[times]         <- temp5[[8]]
  mse_alpha3[times]         <- temp5[[9]]
  
}


result_com <- round(c(mean(Accuracy_com),sd(Accuracy_com),
                      mean(Precision_com),mean(Recall_com),mean(F1_com),
                      mean(mse_alpha2),sd(mse_alpha2),
                      mean(mse_alpha3),sd(mse_alpha3)),6)
print(result_com)

stargazer(result_com, title = "Evaluation",  align = F, type = "latex")
######### The end of missing rate = 0 ####################



# NN=c(30,45,45,45,45,45,45) # N=300,missing rate=0.9
# NN=c(60,90,90,90,90,90,90) # N=600,missing rate=0.9
M0=10
##################################################################
######### MFPCA_complete_data #########
psi.1.hat<-psi.2.hat<-psi.3.hat<-
  x.1.score<-x.2.score<-x.3.score<-
  x.1.score_NA<-x.2.score_NA<-x.3.score_NA<-
  rho.hat_std_com<-vector('list',Iter.times )

source("MFPCA_complete_data_setting2.R")
for (times in 1:Iter.times){
  
  same<-MFPCA_complete_data_setting2(NN, N, T1, T2, T3, x_std[[times]], t.1h, t.2h, t.3h)
  psi.1.hat[[times]]         <-same[[1]]
  psi.2.hat[[times]]         <-same[[2]]
  psi.3.hat[[times]]         <-same[[3]]
  x.1.score_NA[[times]]      <-same[[4]]
  x.2.score_NA[[times]]      <-same[[5]]
  x.3.score_NA[[times]]      <-same[[6]]
  x.1.score[[times]]         <-same[[7]]
  x.2.score[[times]]         <-same[[8]]
  x.3.score[[times]]         <-same[[9]]
  rho.hat_std_com[[times]]   <-same[[10]]
  
}
######### The end of MFPCA_complete_data #########



##################################################################
######## Factor regression based on the CMI method #########
Accuracy_CMI<-Precision_CMI<-Recall_CMI<-F1_CMI<-AIC_CMI<-
  mse_alpha2_CMI<-mse_alpha3_CMI<-array()
x.1.score.hat<-x.2.score.hat<-x.3.score.hat<-rho.hat_std_CMI<-
  alpha2.hat_CMI<-alpha3.hat_CMI<-vector('list',Iter.times )

source("Imputing_data_CMI_setting2.R")
for (times in 1:Iter.times) {
  
  temp1 <- Imputing_data_CMI_setting2(NN, x_std[[times]], x.1.score[[times]], x.2.score[[times]], x.3.score[[times]])
  x.1.score.hat[[times]]    <- temp1[[1]]
  x.2.score.hat[[times]]    <- temp1[[2]]
  x.3.score.hat[[times]]    <- temp1[[3]]
  
}


source("Construct_factor_PCA.R")
for (times in 1:Iter.times){
  
  temp2 <- Construct_factor_PCA(x_std[[times]], psi.1.hat[[times]], psi.2.hat[[times]], psi.3.hat[[times]], 
                                x.1.score.hat[[times]], x.2.score.hat[[times]], x.3.score.hat[[times]])
  rho.hat_std_CMI[[times]]   <- temp2[[1]]
  
}


source("Factor_regression_Imputed_PCA.R")
for (times in 1:Iter.times){
  
  temp3 <- Factor_regression_Imputed_PCA(rho.hat_std_CMI[[times]], alpha2, alpha3, y[[times]])
  Accuracy_CMI[times]        <- temp3[[1]]
  Precision_CMI[times]       <- temp3[[2]]
  Recall_CMI[times]          <- temp3[[3]]
  F1_CMI[times]              <- temp3[[4]]
  AIC_CMI[times]             <- temp3[[5]]
  alpha2.hat_CMI[[times]]    <- temp3[[6]]
  alpha3.hat_CMI[[times]]    <- temp3[[7]]
  mse_alpha2_CMI[times]      <- temp3[[8]]
  mse_alpha3_CMI[times]      <- temp3[[9]]
  
}
######## The end of factor regression based on the CMI method #########



##################################################################
######## Factor regression based on the MBI method #########
Accuracy_MBI<-Precision_MBI<-Recall_MBI<-F1_MBI<-AIC_MBI<-
  mse_alpha2_MBI<-mse_alpha3_MBI<-array()
x.1.score.hat<-x.2.score.hat<-x.3.score.hat<-rho.hat_std_MBI<-
  alpha2.hat_MBI<-alpha3.hat_MBI<-vector('list',Iter.times)

source("Imputing_data_MBI_setting2.R")
for (times in 1:Iter.times) {
  
  temp1 <- Imputing_data_MBI_setting2(NN, x_std[[times]], x.1.score_NA[[times]], x.2.score_NA[[times]], x.3.score_NA[[times]])
  x.1.score.hat[[times]]    <- temp1[[1]]
  x.2.score.hat[[times]]    <- temp1[[2]]
  x.3.score.hat[[times]]    <- temp1[[3]]
  
}


source("Construct_factor_PCA.R")
for (times in 1:Iter.times){
  
  temp2 <- Construct_factor_PCA(x_std[[times]], psi.1.hat[[times]], psi.2.hat[[times]], psi.3.hat[[times]], 
                                x.1.score.hat[[times]], x.2.score.hat[[times]], x.3.score.hat[[times]])
  rho.hat_std_MBI[[times]]  <- temp2[[1]]
  
}


source("Factor_regression_Imputed_PCA.R")
for (times in 1:Iter.times){
  
  temp3 <- Factor_regression_Imputed_PCA(rho.hat_std_MBI[[times]], alpha2, alpha3, y[[times]])
  Accuracy_MBI[times]       <- temp3[[1]]
  Precision_MBI[times]      <- temp3[[2]]
  Recall_MBI[times]         <- temp3[[3]]
  F1_MBI[times]             <- temp3[[4]]
  AIC_MBI[times]            <- temp3[[5]]
  alpha2.hat_MBI[[times]]   <- temp3[[6]]
  alpha3.hat_MBI[[times]]   <- temp3[[7]]
  mse_alpha2_MBI[times]     <- temp3[[8]]
  mse_alpha3_MBI[times]     <- temp3[[9]]
  
}
######## The end of factor regression based on the MBI method #########



#result----
result <- round(rbind(
  c(mean(Accuracy_CMI),sd(Accuracy_CMI),mean(Precision_CMI),mean(Recall_CMI),mean(F1_CMI),
    mean(mse_alpha2_CMI),sd(mse_alpha2_CMI),mean(mse_alpha3_CMI),sd(mse_alpha3_CMI)),
  c(mean(Accuracy_MBI),sd(Accuracy_MBI),mean(Precision_MBI),mean(Recall_MBI),mean(F1_MBI),
    mean(mse_alpha2_MBI),sd(mse_alpha2_MBI),mean(mse_alpha3_MBI),sd(mse_alpha3_MBI))),4)
print(result)
stargazer(result, title = "Evaluation",  align = F, type = "latex")