MCCA_complete_data_setting2<-function(NN, N, T1, T2, T3, x_std, t.1h, t.2h, t.3h){
  
  ##### Computing the FPC scores and curves for each data source by SVD method ############# 
  s1<-svd(x_std[c(1:sum(NN[1:3]),(sum(NN[1:4])+1):sum(NN[1:5])),1:T1]/sqrt(sum(NN[c(1:3,5)])))  ## SVD for x.1 on the observed data NN[1,2,3,5]
  phi.1.hat<-t(s1$v[,1:k1]) * (t.1h/T1)^(-0.5)                                                  ## The univariate FPC curves of x.1 with order k1*T1
  x.1.score<-x_std[c(1:sum(NN[1:3]),(sum(NN[1:4])+1):sum(NN[1:5])),1:T1] %*% t(phi.1.hat) * (t.1h/T1)## The univariate FPC scores of x.1 
  
  x.1.score_NA <- matrix(NA,N,k1)
  x.1.score_NA[1:sum(NN[1:3]),] <- x.1.score[1:sum(NN[1:3]),]
  x.1.score_NA[(sum(NN[1:4])+1):(sum(NN[1:5])),] <- x.1.score[(sum(NN[1:3])+1):(sum(NN[1:3])+NN[5]),]
  
  
  s2<-svd(x_std[c(1:sum(NN[1:2]),(sum(NN[1:3])+1):sum(NN[1:4]),(sum(NN[1:5])+1):sum(NN[1:6])),(T1+1):(T1+T2)]/sqrt((sum(NN[c(1:2,4,6)]))))## SVD for x.2 on the observed data NN[1,2,4,6]
  phi.2.hat<-t(s2$v[,1:k2]) * (t.2h/T2)^(-0.5)                              ## The univariate FPC curves of x.2 with order k2*T2
  x.2.score<-x_std[c(1:sum(NN[1:2]),(sum(NN[1:3])+1):sum(NN[1:4]),(sum(NN[1:5])+1):sum(NN[1:6])),(T1+1):(T1+T2)] %*% t(phi.2.hat) * (t.2h/T2) #The univariate FPCA of x.2
  
  x.2.score_NA <- matrix(NA, N, k2)
  x.2.score_NA[1:sum(NN[1:2]),] <- x.2.score[1:sum(NN[1:2]),]
  x.2.score_NA[(sum(NN[1:3])+1):(sum(NN[1:4])),] <- x.2.score[(sum(NN[1:2])+1):(sum(NN[1:2])+NN[4]),]
  x.2.score_NA[(sum(NN[1:5])+1):(sum(NN[1:6])),] <- x.2.score[(sum(NN[1:2])+NN[4]+1):(sum(NN[1:2])+NN[4]+NN[6]),]  
  
  
  s3<-svd(x_std[c(1:NN[1],(sum(NN[1:2])+1):sum(NN[1:4]),(sum(NN[1:6])+1):sum(NN[1:7])),(T1+T2+1):(T1+T2+T3)]/sqrt((NN[1]+sum(NN[3:4])+NN[7])))## SVD for x.3 on the observed data NN[1,3,4,7] 
  phi.3.hat<-t(s3$v[,1:k3]) * (t.3h/T3)^(-0.5)                               ## The univariate FPC curves of x.3 with order k3*T3
  x.3.score<-x_std[c(1:NN[1],(sum(NN[1:2])+1):sum(NN[1:4]),(sum(NN[1:6])+1):sum(NN[1:7])),(T1+T2+1):(T1+T2+T3)] %*% t(phi.3.hat) * (t.3h/T3) #The univariate FPCA of x.3
  
  x.3.score_NA <- matrix(NA, N, k3)
  x.3.score_NA[1:NN[1],] <- x.3.score[1:NN[1],]
  x.3.score_NA[(sum(NN[1:2])+1):(sum(NN[1:4])),] <- x.3.score[(NN[1]+1):(NN[1]+sum(NN[3:4])),]
  x.3.score_NA[(sum(NN[1:6])+1):(sum(NN[1:7])),] <- x.3.score[(NN[1]+sum(NN[3:4])+1):(NN[1]+sum(NN[3:4])+NN[7]),]
  ##### The end of Computing the FPC scores and curves for each data source by SVD method #############  
  
  
  ######### The multivariate FPCA of x.1,x.2 and x.3 on the complete-data #########
  score<-cbind(x.1.score[1:NN[1],],x.2.score[1:NN[1],],x.3.score[1:NN[1],])    ##  N1*(k1+k2+k3)
  z.hat<-t(score) %*% score /(NN[1]-1)
  
  psi.1.hat<-t(eigen(z.hat)$vec[1:k1,1:(k1+k2+k3)]) %*% phi.1.hat                     ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2+k3)*T1
  psi.2.hat<-t(eigen(z.hat)$vec[(k1+1):(k1+k2),1:(k1+k2+k3)]) %*% phi.2.hat           ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2+k3)*T2
  psi.3.hat<-t(eigen(z.hat)$vec[(k1+k2+1):(k1+k2+k3),1:(k1+k2+k3)]) %*% phi.3.hat     ## The estimated Multivariate FPC eigenfunctions of x.1 with order (k1+k2+k3)*T3
  
  
  ######### The multivariate FPCA of x.1 and x.2 on the complete-data #########
  Z1 = x.1.score[1:NN[1],]
  Z2 = x.2.score[1:NN[1],]
  Z3 = x.3.score[1:NN[1],]
  
  Omega1 = Z1%*%solve(t(Z1)%*%Z1)%*%t(Z1)
  Omega2 = Z2%*%solve(t(Z2)%*%Z2)%*%t(Z2)
  Omega3 = Z3%*%solve(t(Z3)%*%Z3)%*%t(Z3)
  
  evd = eigen(Omega1 + Omega2 + Omega3)
  
  f_com = evd$vectors[,1:M0] 
  
  return(list(psi.1.hat,psi.2.hat,psi.3.hat,
              x.1.score_NA,x.2.score_NA,x.3.score_NA,
              x.1.score,x.2.score,x.3.score,f_com))
  
}